@@ -17,6 +17,7 @@ checkfail()
 #############
 
 RELEASE=0
+GDB_FILE=""
 while [ $# -gt 0 ]; do
     case $1 in
         help|--help)
@@ -34,6 +35,10 @@ while [ $# -gt 0 ]; do
         release|--release)
             RELEASE=1
             ;;
+        --gdb)
+            GDB_FILE="$2"
+            shift
+            ;;
     esac
     shift
 done
@@ -295,6 +300,12 @@ SRC_DIR=$PWD
 # stub libraries
 NDK_TOOLCHAIN_PATH=`echo ${ANDROID_NDK}/toolchains/${PATH_HOST}-${GCCVER}/prebuilt/\`uname|tr A-Z a-z\`-*/bin`
 CROSS_COMPILE=${NDK_TOOLCHAIN_PATH}/${TARGET_TUPLE}-
+
+if [ ! -z "$GDB_FILE" ];then
+    ${CROSS_COMPILE}gdb "$GDB_FILE"
+    exit 0
+fi
+
 export PATH=${NDK_TOOLCHAIN_PATH}:${PATH}
 
 ###############
@@ -633,3 +644,21 @@ $ANDROID_NDK/ndk-build -C libvlc \
     HAVE_64=${HAVE_64} \
     NDK_PROJECT_PATH=jni \
     NDK_DEBUG=${NDK_DEBUG}
+
+checkfail "ndk-build failed"
+
+if [ "$RELEASE" = 1 ]; then
+    DBG_LIB_DIR=libvlc/jni/obj/local/${ANDROID_ABI}
+    OUT_LIB_DIR=libvlc/jni/libs/${ANDROID_ABI}
+    VERSION=$(grep "android:versionName" vlc-android/AndroidManifest.xml|cut -d\" -f 2)
+    OUT_DBG_DIR=.dbg/${ANDROID_ABI}/$VERSION
+
+    mkdir -p $OUT_DBG_DIR
+
+    for lib in ${DBG_LIB_DIR}/*.so; do
+        ${CROSS_COMPILE}objcopy --only-keep-debug "$lib" "$OUT_DBG_DIR/`basename $lib.dbg`"; \
+    done
+    for lib in ${OUT_LIB_DIR}/*.so; do
+        ${CROSS_COMPILE}objcopy --add-gnu-debuglink="$OUT_DBG_DIR/`basename $lib.dbg`" "$lib" ; \
+    done
+fi
