@@ -103,8 +103,6 @@ public class LibVLC {
     public native void attachSubtitlesSurface(Surface surface);
     public native void detachSubtitlesSurface();
 
-    public native void eventVideoPlayerActivityCreated(boolean created);
-
     /* Load library before object instantiation */
     static {
         if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.GINGERBREAD_MR1) {
@@ -635,6 +633,8 @@ public class LibVLC {
 
     public native int getVideoTracksCount();
 
+    public native int setVideoTrack(int index);
+
     public native int addSubtitleTrack(String path);
 
     public native Map<Integer,String> getSpuTrackDescription();
