@@ -290,20 +290,16 @@ public class AudioServiceController implements IAudioPlayerControl {
         }
     }
 
-    public void load(List<String> mediaPathList, int position) {
-        load(mediaPathList, position, false);
-    }
-
-    public void load(String mediaPath, boolean noVideo) {
+    public void load(String mediaPath) {
         ArrayList<String> arrayList = new ArrayList<String>();
         arrayList.add(mediaPath);
-        load(arrayList, 0, noVideo);
+        load(arrayList, 0);
     }
 
-    public void load(List<String> mediaPathList, int position, boolean noVideo) {
+    public void load(List<String> mediaPathList, int position) {
         remoteProcedureCall(mAudioServiceBinder, Void.class, (Void)null, "load",
-                new Class<?>[] { List.class, int.class, boolean.class },
-                new Object[] { mediaPathList, position, noVideo } );
+                new Class<?>[] { List.class, int.class },
+                new Object[] { mediaPathList, position } );
     }
 
     public void append(String mediaPath) {
@@ -353,21 +349,18 @@ public class AudioServiceController implements IAudioPlayerControl {
 
     public void stop() {
         remoteProcedureCall(mAudioServiceBinder, Void.class, (Void)null, "stop", null, null);
-        updateAudioPlayer();
     }
 
     public void showWithoutParse(int u) {
         remoteProcedureCall(mAudioServiceBinder, Void.class, (Void)null, "showWithoutParse",
                 new Class<?>[] { int.class },
                 new Object[] { u } );
-        updateAudioPlayer();
     }
 
     public void playIndex(int i) {
         remoteProcedureCall(mAudioServiceBinder, Void.class, (Void)null, "playIndex",
                 new Class<?>[] { int.class },
                 new Object[] { i } );
-        updateAudioPlayer();
     }
 
     @Override
@@ -413,13 +406,11 @@ public class AudioServiceController implements IAudioPlayerControl {
     @Override
     public void pause() {
         remoteProcedureCall(mAudioServiceBinder, Void.class, (Void)null, "pause", null, null);
-        updateAudioPlayer();
     }
 
     @Override
     public void play() {
         remoteProcedureCall(mAudioServiceBinder, Void.class, (Void)null, "play", null, null);
-        updateAudioPlayer();
     }
 
     @Override
@@ -513,4 +504,9 @@ public class AudioServiceController implements IAudioPlayerControl {
     public float getRate() {
         return remoteProcedureCall(mAudioServiceBinder, Float.class, (float) 1.0, "getRate", null, null);
     }
+
+    @Override
+    public void handleVout() {
+        remoteProcedureCall(mAudioServiceBinder, Void.class, (Void)null, "handleVout", null, null);
+    }
 }
