@@ -42,8 +42,8 @@ import android.support.v4.app.FragmentTransaction;
 import android.support.v4.view.GravityCompat;
 import android.support.v4.view.MenuItemCompat;
 import android.support.v7.app.ActionBar;
-import android.support.v7.app.ActionBarActivity;
 import android.support.v7.app.ActionBarDrawerToggle;
+import android.support.v7.app.AppCompatActivity;
 import android.support.v7.widget.SearchView;
 import android.support.v7.widget.Toolbar;
 import android.util.Log;
@@ -63,19 +63,19 @@ import android.widget.ListView;
 import android.widget.ProgressBar;
 import android.widget.TextView;
 
-import org.videolan.libvlc.LibVlcException;
 import org.videolan.libvlc.LibVlcUtil;
 import org.videolan.vlc.BuildConfig;
 import org.videolan.vlc.MediaDatabase;
 import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.R;
-import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.audio.AudioService;
 import org.videolan.vlc.audio.AudioServiceController;
 import org.videolan.vlc.gui.SidebarAdapter.SidebarEntry;
 import org.videolan.vlc.gui.audio.AudioBrowserFragment;
 import org.videolan.vlc.gui.audio.AudioPlayer;
-import org.videolan.vlc.gui.network.NetworkFragment;
+import org.videolan.vlc.gui.browser.BaseBrowserFragment;
+import org.videolan.vlc.gui.browser.MediaBrowserFragment;
+import org.videolan.vlc.gui.browser.NetworkBrowserFragment;
 import org.videolan.vlc.gui.video.VideoGridFragment;
 import org.videolan.vlc.gui.video.VideoListAdapter;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
@@ -88,7 +88,7 @@ import org.videolan.vlc.util.WeakHandler;
 import org.videolan.vlc.widget.HackyDrawerLayout;
 import org.videolan.vlc.widget.SlidingPaneLayout;
 
-public class MainActivity extends ActionBarActivity implements OnItemClickListener, SearchSuggestionsAdapter.SuggestionDisplay, FilterQueryProvider {
+public class MainActivity extends AppCompatActivity implements OnItemClickListener, SearchSuggestionsAdapter.SuggestionDisplay, FilterQueryProvider {
     public final static String TAG = "VLC/MainActivity";
 
     public static final String ACTION_SHOW_PLAYER = "org.videolan.vlc.gui.ShowPlayer";
@@ -109,7 +109,6 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
     private HackyDrawerLayout mRootContainer;
     private ListView mListView;
     private ActionBarDrawerToggle mDrawerToggle;
-    private View mSideMenu;
 
     private View mInfoLayout;
     private ProgressBar mInfoProgress;
@@ -171,7 +170,6 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         mSlidingPane = (SlidingPaneLayout) findViewById(R.id.pane);
         mSlidingPane.setPanelSlideListener(mPanelSlideListener);
 
-        mSideMenu = findViewById(R.id.side_menu);
         mListView = (ListView)findViewById(R.id.sidelist);
         mListView.setFooterDividersEnabled(true);
         mSidebarAdapter = new SidebarAdapter(this);
@@ -200,8 +198,8 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
             @Override
             public void onDrawerClosed(View drawerView) {
                 super.onDrawerClosed(drawerView);
-                if (getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder) instanceof BrowserFragment)
-                    ((BrowserFragment) getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder)).setReadyToDisplay(true);
+                if (getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder) instanceof MediaBrowserFragment)
+                    ((MediaBrowserFragment) getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder)).setReadyToDisplay(true);
             }
         };
 
@@ -214,6 +212,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
         /* Set up the audio player */
         mAudioPlayer = new AudioPlayer();
+        mAudioPlayer.setUserVisibleHint(false);
         mAudioController = AudioServiceController.getInstance();
 
         getSupportFragmentManager().beginTransaction()
@@ -229,7 +228,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
             mHandler.postDelayed(new Runnable() {
                 @Override
                 public void run() {
-                    mRootContainer.openDrawer(mSideMenu);
+                    mRootContainer.openDrawer(mListView);
                 }
             }, 500);
         }
@@ -279,6 +278,8 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         /* Load media items from database and storage */
         if (mScanNeeded)
             MediaLibrary.getInstance().loadMediaItems();
+        if (mSlidingPane.getState() == mSlidingPane.STATE_CLOSED)
+            mActionBar.hide();
    }
 
     @Override
@@ -367,10 +368,10 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
     @Override
     public void onBackPressed() {
             /* Close the menu first */
-        if(mRootContainer.isDrawerOpen(mSideMenu)) {
+        if(mRootContainer.isDrawerOpen(mListView)) {
             if (mFocusedPrior != 0)
                 requestFocusOnSearch();
-            mRootContainer.closeDrawer(mSideMenu);
+            mRootContainer.closeDrawer(mListView);
             return;
         }
 
@@ -380,17 +381,11 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
         if (mCurrentFragment!= null) {
             // If it's the directory view, a "backpressed" action shows a parent.
-            if (mCurrentFragment.equals(SidebarEntry.ID_DIRECTORIES)) {
-                DirectoryViewFragment directoryView = (DirectoryViewFragment) getFragment(mCurrentFragment);
-                if (!directoryView.isRootDirectory()) {
-                    directoryView.showParentDirectory();
-                    return;
-                }
-            } else if (mCurrentFragment.equals(SidebarEntry.ID_NETWORK)){
-                NetworkFragment networkFragment = (NetworkFragment) getSupportFragmentManager()
+            if (mCurrentFragment.equals(SidebarEntry.ID_NETWORK) || mCurrentFragment.equals(SidebarEntry.ID_DIRECTORIES)){
+                BaseBrowserFragment browserFragment = (BaseBrowserFragment) getSupportFragmentManager()
                         .findFragmentById(R.id.fragment_placeholder);
-                if (networkFragment !=null && !networkFragment.isRootDirectory()) {
-                    networkFragment.goBack();
+                if (browserFragment !=null && !browserFragment.isRootDirectory()) {
+                    browserFragment.goBack();
                     return;
                 }
             }
@@ -504,11 +499,11 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                     item.setTitle(R.string.sortby_date);
         }
 
-        boolean networkSave = current instanceof NetworkFragment && !((NetworkFragment)current).isRootDirectory();
+        boolean networkSave = current instanceof NetworkBrowserFragment && !((NetworkBrowserFragment)current).isRootDirectory();
         if (networkSave) {
             MenuItem item = menu.findItem(R.id.ml_menu_save);
             item.setVisible(true);
-            String mrl = ((NetworkFragment)current).mMrl;
+            String mrl = ((BaseBrowserFragment)current).mMrl;
             item.setIcon(MediaDatabase.getInstance().networkFavExists(mrl) ?
                     R.drawable.ic_menu_bookmark_w :
                     R.drawable.ic_menu_bookmark_outline_w);
@@ -553,7 +548,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                 }
                 break;
             case R.id.ml_menu_equalizer:
-                showSecondaryFragment("equalizer");
+                showSecondaryFragment(SecondaryActivity.EQUALIZER);
                 break;
             // Refresh
             case R.id.ml_menu_refresh:
@@ -591,11 +586,11 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
             case R.id.ml_menu_save:
                 if (current == null)
                     break;
-                ((NetworkFragment)current).toggleFavorite();
+                ((NetworkBrowserFragment)current).toggleFavorite();
                 item.setIcon(R.drawable.ic_menu_bookmark_w);
                 break;
         }
-        mRootContainer.closeDrawer(mSideMenu);
+        mRootContainer.closeDrawer(mListView);
         return super.onOptionsItemSelected(item);
     }
 
@@ -715,8 +710,8 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
             v.setNextFocusRightId(R.id.ml_menu_search);
             if (LibVlcUtil.isHoneycombOrLater())
                 v.setNextFocusForwardId(mActionBarIconId);
-            findViewById(R.id.ml_menu_search).setNextFocusLeftId(
-                mActionBarIconId);
+            if (findViewById(R.id.ml_menu_search) != null)
+                findViewById(R.id.ml_menu_search).setNextFocusLeftId(mActionBarIconId);
         }
         return super.onKeyUp(keyCode, event);
     }
@@ -877,6 +872,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                 if (resId != 0)
                     mSlidingPane.setShadowResource(resId);
                 mAudioPlayer.setHeaderVisibilities(false, false, true, true, true, false);
+                mAudioPlayer.setUserVisibleHint(false);
                 mRootContainer.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_UNLOCKED);
                 removeTipViewIfDisplayed();
                 mAudioPlayer.showAudioPlayerTips();
@@ -884,12 +880,14 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
             @Override
             public void onPanelOpenedEntirely() {
+                mAudioPlayer.setUserVisibleHint(false);
                 mSlidingPane.setShadowDrawable(null);
                 mRootContainer.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_UNLOCKED);
             }
 
             @Override
             public void onPanelClosed() {
+                mAudioPlayer.setUserVisibleHint(true);
                 mAudioPlayer.setHeaderVisibilities(true, true, false, false, false, true);
                 mRootContainer.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_LOCKED_CLOSED);
                 mAudioPlayer.showPlaylistTips();
@@ -903,7 +901,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
      * @param settingKey the setting key to check if the view must be displayed or not.
      */
     public void showTipViewIfNeeded(final int layoutId, final String settingKey) {
-        if (!mSettings.getBoolean(settingKey, false) && AndroidDevices.hasTsp()) {
+        if (!mSettings.getBoolean(settingKey, false) && !BuildConfig.tv) {
             removeTipViewIfDisplayed();
             View v = LayoutInflater.from(this).inflate(layoutId, null);
             mRootContainer.addView(v,
@@ -942,20 +940,6 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         }
     }
 
-    public void onClick(View v){
-        switch (v.getId()){
-            case R.id.settings:
-            case R.id.settings_icon:
-                startActivityForResult(new Intent(this, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
-                break;
-            case R.id.about:
-            case R.id.about_icon:
-                showSecondaryFragment("about");
-                break;
-        }
-        mRootContainer.closeDrawer(mSideMenu);
-    }
-
     @Override
     public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
         SidebarAdapter.SidebarEntry entry = (SidebarEntry) mListView.getItemAtPosition(position);
@@ -964,7 +948,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         if(current == null || (entry != null && current.getTag().equals(entry.id))) { /* Already selected */
             if (mFocusedPrior != 0)
                 requestFocusOnSearch();
-            mRootContainer.closeDrawer(mSideMenu);
+            mRootContainer.closeDrawer(mListView);
             return;
         }
 
@@ -979,8 +963,8 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
                 /* Switch the fragment */
             Fragment fragment = getFragment(entry.id);
-            if (fragment instanceof BrowserFragment)
-                ((BrowserFragment)fragment).setReadyToDisplay(false);
+            if (fragment instanceof MediaBrowserFragment)
+                ((MediaBrowserFragment)fragment).setReadyToDisplay(false);
             FragmentTransaction ft = getSupportFragmentManager().beginTransaction();
             ft.replace(R.id.fragment_placeholder, fragment, entry.id);
             ft.addToBackStack(mCurrentFragment);
@@ -990,10 +974,11 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
             if (mFocusedPrior != 0)
                 requestFocusOnSearch();
-            mRootContainer.closeDrawer(mSideMenu);
-        }else if (entry.attributeID == R.attr.ic_menu_preferences){
+        } else if (entry.type == SidebarEntry.TYPE_SECONDARY_FRAGMENT)
+            showSecondaryFragment(SecondaryActivity.ABOUT);
+        else if (entry.attributeID == R.attr.ic_menu_preferences)
             startActivityForResult(new Intent(this, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
-        }
+        mRootContainer.closeDrawer(mListView);
     }
 
     private void requestFocusOnSearch() {
