@@ -3,6 +3,7 @@
  *  SecondaryActivity.java
  * **************************************************************************
  *  Copyright © 2015 VLC authors and VideoLAN
+ *  Author: Geoffrey Métais
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,9 +26,8 @@ package org.videolan.vlc.gui;
 import android.os.Bundle;
 import android.preference.PreferenceManager;
 import android.support.v4.app.Fragment;
-import android.support.v4.app.FragmentTransaction;
 import android.support.v7.app.ActionBar;
-import android.support.v7.app.ActionBarActivity;
+import android.support.v7.app.AppCompatActivity;
 import android.support.v7.widget.Toolbar;
 import android.view.Menu;
 import android.view.MenuItem;
@@ -35,20 +35,28 @@ import android.view.MenuItem;
 import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
+import org.videolan.vlc.gui.audio.AudioAlbumFragment;
 import org.videolan.vlc.gui.audio.AudioAlbumsSongsFragment;
 import org.videolan.vlc.gui.audio.EqualizerFragment;
 import org.videolan.vlc.gui.video.MediaInfoFragment;
 import org.videolan.vlc.gui.video.VideoGridFragment;
 import org.videolan.vlc.gui.video.VideoListAdapter;
-import org.videolan.vlc.interfaces.IRefreshable;
 import org.videolan.vlc.interfaces.ISortable;
-import org.videolan.vlc.util.Util;
 
 import java.util.ArrayList;
 
-public class SecondaryActivity  extends ActionBarActivity {
+public class SecondaryActivity  extends AppCompatActivity {
+    public final static String TAG = "VLC/EqualizerFragment";
+
+    public static final String ALBUMS_SONGS = "albumsSongs";
+    public static final String ALBUM = "album";
+    public static final String EQUALIZER = "equalizer";
+    public static final String ABOUT = "about";
+    public static final String MEDIA_INFO = "mediaInfo";
+    public static final String VIDEO_GROUP_LIST = "videoGroupList";
 
     Fragment mFragment;
+
     @Override
     protected void onCreate(Bundle savedInstanceState) {
         /* Theme must be applied before super.onCreate */
@@ -61,15 +69,18 @@ public class SecondaryActivity  extends ActionBarActivity {
         setSupportActionBar((Toolbar) findViewById(R.id.main_toolbar));
         ActionBar actionBar = getSupportActionBar();
         actionBar.setDisplayHomeAsUpEnabled(true);
-        String fragmentId = getIntent().getStringExtra("fragment");
-        fetchSecondaryFragment(fragmentId);
-        if (mFragment == null){
-            finish();
-            return;
+
+        if (getSupportFragmentManager().getFragments() == null) {
+            String fragmentId = getIntent().getStringExtra("fragment");
+            fetchSecondaryFragment(fragmentId);
+            if (mFragment == null){
+                finish();
+                return;
+            }
+            getSupportFragmentManager().beginTransaction()
+            .add(R.id.fragment_placeholder, mFragment)
+            .commit();
         }
-        FragmentTransaction ft = getSupportFragmentManager().beginTransaction();
-            ft.add(R.id.fragment_placeholder, mFragment);
-            ft.commit();
     }
 
     @Override
@@ -102,19 +113,24 @@ public class SecondaryActivity  extends ActionBarActivity {
     }
 
     public void fetchSecondaryFragment(String id) {
-        if (id.equals("albumsSongs")) {
+        if (id.equals(ALBUMS_SONGS)) {
             ArrayList<MediaWrapper> mediaList = getIntent().getParcelableArrayListExtra("list");
             String filter = getIntent().getStringExtra("filter");
             mFragment = new AudioAlbumsSongsFragment();
-            ((AudioAlbumsSongsFragment)mFragment).setMediaList(mediaList, filter);
-        } else if(id.equals("equalizer")) {
+            ((AudioAlbumsSongsFragment) mFragment).setMediaList(mediaList, filter);
+        } else if(id.equals(ALBUM)) {
+            ArrayList<MediaWrapper> mediaList = getIntent().getParcelableArrayListExtra("list");
+            String filter = getIntent().getStringExtra("filter");
+            mFragment = new AudioAlbumFragment();
+            ((AudioAlbumFragment) mFragment).setMediaList(mediaList, filter);
+        } else if(id.equals(EQUALIZER)) {
             mFragment = new EqualizerFragment();
-        } else if(id.equals("about")) {
+        } else if(id.equals(ABOUT)) {
             mFragment = new AboutFragment();
-        } else if(id.equals("mediaInfo")) {
+        } else if(id.equals(MEDIA_INFO)) {
             mFragment = new MediaInfoFragment();
             ((MediaInfoFragment)mFragment).setMediaLocation(getIntent().getStringExtra("param"));
-        } else if(id.equals("videoGroupList")) {
+        } else if(id.equals(VIDEO_GROUP_LIST)) {
             mFragment = new VideoGridFragment();
             ((VideoGridFragment)mFragment).setGroup(getIntent().getStringExtra("param"));
         }
