@@ -28,7 +28,9 @@ import org.videolan.vlc.BuildConfig;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.audio.AudioBrowserFragment;
-import org.videolan.vlc.gui.network.NetworkFragment;
+import org.videolan.vlc.gui.browser.BaseBrowserFragment;
+import org.videolan.vlc.gui.browser.FileBrowserFragment;
+import org.videolan.vlc.gui.browser.NetworkBrowserFragment;
 import org.videolan.vlc.gui.video.VideoGridFragment;
 import org.videolan.vlc.util.Util;
 
@@ -47,9 +49,10 @@ import android.widget.TextView;
 public class SidebarAdapter extends BaseAdapter {
     public final static String TAG = "VLC/SidebarAdapter";
 
-    static class SidebarEntry {
+    public static class SidebarEntry {
         public static final  int TYPE_FRAGMENT = 0;
         public static final  int TYPE_ACTION = 1;
+        public static final  int TYPE_SECONDARY_FRAGMENT = 2;
 
         public static final String ID_VIDEO = "video";
         public static final String ID_AUDIO = "audio";
@@ -58,6 +61,7 @@ public class SidebarAdapter extends BaseAdapter {
         public static final String ID_HISTORY = "history";
         public static final String ID_MRL = "mrl";
         public static final String ID_PREFERENCES = "preferences";
+        public static final String ID_ABOUT = "about";
 
         String id;
         String name;
@@ -90,10 +94,11 @@ public class SidebarAdapter extends BaseAdapter {
         if (BuildConfig.DEBUG)
             entries.add(new SidebarEntry(SidebarEntry.ID_HISTORY, R.string.history, R.attr.ic_menu_history, SidebarEntry.TYPE_FRAGMENT));
         sidebarFragments = new ArrayList<String>();
+        entries.add(new SidebarEntry(SidebarEntry.ID_PREFERENCES, R.string.preferences, R.attr.ic_menu_preferences, SidebarEntry.TYPE_ACTION));
+        entries.add(new SidebarEntry(SidebarEntry.ID_ABOUT, R.string.about, R.attr.ic_menu_cone, SidebarEntry.TYPE_SECONDARY_FRAGMENT));
         for(SidebarEntry e : entries) {
             sidebarFragments.add(e.id);
         }
-//        entries.add(new SidebarEntry(SidebarEntry.ID_PREFERENCES, R.string.preferences, R.attr.ic_menu_preferences, SidebarEntry.TYPE_ACTION));
     }
 
     public SidebarAdapter(Context context) {
@@ -137,10 +142,8 @@ public class SidebarAdapter extends BaseAdapter {
         // Set in selected the current item.
         if (TextUtils.equals(mCurrentFragmentId,sidebarEntry.id)) {
             textView.setTypeface(null, Typeface.BOLD);
-            v.setBackgroundColor(Util.getColorFromAttribute(mContext, R.attr.background_menu_selected));
         } else {
             textView.setTypeface(null, Typeface.NORMAL);
-            v.setBackgroundColor(Util.getColorFromAttribute(mContext, R.attr.background_menu));
         }
 
         return v;
@@ -163,13 +166,13 @@ public class SidebarAdapter extends BaseAdapter {
         } else if(id.equals(SidebarEntry.ID_VIDEO)) {
             f = new VideoGridFragment();
         } else if(id.endsWith(SidebarEntry.ID_DIRECTORIES)) {
-            f = new DirectoryViewFragment();
+            f = new FileBrowserFragment();
         } else if(id.equals(SidebarEntry.ID_HISTORY)) {
             f = new HistoryFragment();
         } else if(id.equals(SidebarEntry.ID_MRL)) {
             f = new MRLPanelFragment();
         } else if(id.equals(SidebarEntry.ID_NETWORK)) {
-            f = new NetworkFragment();
+            f = new NetworkBrowserFragment();
         }
         else {
             mCurrentFragmentId = prevFragmentId; // Restore the current fragment id.
