@@ -21,13 +21,13 @@
 package org.videolan.vlc.gui.audio;
 
 import android.annotation.TargetApi;
-import android.app.AlertDialog;
 import android.content.Intent;
 import android.os.Build;
 import android.os.Bundle;
 import android.os.Handler;
 import android.os.Message;
 import android.support.v4.view.ViewPager;
+import android.support.v7.app.AlertDialog;
 import android.view.ContextMenu;
 import android.view.ContextMenu.ContextMenuInfo;
 import android.view.KeyEvent;
@@ -52,7 +52,6 @@ import android.widget.TextView;
 
 import com.android.widget.SlidingTabLayout;
 
-import org.videolan.libvlc.LibVLC;
 import org.videolan.libvlc.LibVlcUtil;
 import org.videolan.libvlc.Media;
 import org.videolan.libvlc.util.MediaBrowser;
@@ -61,7 +60,7 @@ import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.audio.AudioServiceController;
-import org.videolan.vlc.gui.BrowserFragment;
+import org.videolan.vlc.gui.browser.MediaBrowserFragment;
 import org.videolan.vlc.gui.CommonDialogs;
 import org.videolan.vlc.gui.MainActivity;
 import org.videolan.vlc.gui.SecondaryActivity;
@@ -82,7 +81,7 @@ import java.util.concurrent.ConcurrentLinkedQueue;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 
-public class AudioBrowserFragment extends BrowserFragment implements SwipeRefreshLayout.OnRefreshListener, SlidingTabLayout.OnTabChangedListener, MediaBrowser.EventListener, IBrowser {
+public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeRefreshLayout.OnRefreshListener, SlidingTabLayout.OnTabChangedListener, MediaBrowser.EventListener, IBrowser {
     public final static String TAG = "VLC/AudioBrowserFragment";
 
     private AudioServiceController mAudioController;
@@ -339,8 +338,12 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
     OnItemClickListener albumListListener = new OnItemClickListener() {
         @Override
         public void onItemClick(AdapterView<?> av, View v, int p, long id) {
-            ArrayList<String> mediaLocation = mAlbumsAdapter.getLocations(p, true);
-            mAudioController.load(mediaLocation, 0);
+            ArrayList<MediaWrapper> mediaList = mAlbumsAdapter.getMedia(p);
+            Intent i = new Intent(getActivity(), SecondaryActivity.class);
+            i.putExtra("fragment", SecondaryActivity.ALBUM);
+            i.putParcelableArrayListExtra("list", mediaList);
+            i.putExtra("filter", Util.getMediaAlbum(getActivity(), mediaList.get(0)));
+            startActivity(i);
         }
     };
 
@@ -349,7 +352,7 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
         public void onItemClick(AdapterView<?> av, View v, int p, long id) {
             ArrayList<MediaWrapper> mediaList = mGenresAdapter.getMedia(p);
             Intent i = new Intent(getActivity(), SecondaryActivity.class);
-            i.putExtra("fragment", "albumsSongs");
+            i.putExtra("fragment", SecondaryActivity.ALBUMS_SONGS);
             i.putParcelableArrayListExtra("list", mediaList);
             i.putExtra("filter", Util.getMediaGenre(getActivity(), mediaList.get(0)));
             startActivity(i);
@@ -362,10 +365,10 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
             ArrayList<MediaWrapper> mediaList = mPlaylistAdapter.getItem(p).mMediaList;
             if (mediaList.size() == 1) {
                 String mediaLocation = mediaList.get(0).getLocation();
-                mAudioController.load(mediaLocation, true);
+                mAudioController.load(mediaLocation);
             } else {
                 ArrayList<String> mediaLocations = mPlaylistAdapter.getLocations(p);
-                mAudioController.load(mediaLocations, 0, true);
+                mAudioController.load(mediaLocations, 0);
             }
         }
     };
@@ -431,6 +434,8 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
                 adapter = mPlaylistAdapter;
             } else
                 return false;
+            if (adapter.getCount() <= groupPosition || adapter.getLocations(groupPosition) == null || adapter.getLocations(groupPosition).isEmpty())
+                return false;
             AlertDialog alertDialog = CommonDialogs.deleteMedia(
                     getActivity(),
                     adapter.getLocations(groupPosition).get(0),
@@ -455,29 +460,33 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
         }
 
         if (id == R.id.audio_list_browser_set_song) {
+            if (mSongsAdapter.getCount() <= groupPosition)
+                return false;
             AudioUtil.setRingtone(mSongsAdapter.getItem(groupPosition).mMediaList.get(0), getActivity());
             return true;
         }
 
         if (useAllItems) {
+            if (mSongsAdapter.getCount() <= groupPosition)
+                return false;
             medias = new ArrayList<String>();
             startPosition = mSongsAdapter.getListWithPosition(medias, groupPosition);
         }
         else {
             startPosition = 0;
-            switch (mode)
-            {
+            AudioBrowserListAdapter adapter = null;
+            switch (mode){
                 case MODE_SONG:
-                    medias = mSongsAdapter.getLocations(groupPosition);
+                    adapter = mSongsAdapter;
                     break;
                 case MODE_ARTIST:
-                    medias = mArtistsAdapter.getLocations(groupPosition);
+                    adapter = mArtistsAdapter;
                     break;
                 case MODE_ALBUM:
-                    medias = mAlbumsAdapter.getLocations(groupPosition, true);
+                    adapter = mAlbumsAdapter;
                     break;
                 case MODE_GENRE:
-                    medias = mGenresAdapter.getLocations(groupPosition);
+                    adapter = mGenresAdapter;
                     break;
                 case MODE_PLAYLIST: //For file playlist, we browse tracks with mediabrowser, and add them in callbacks onMediaAdded and onBrowseEnd
                     medias = mPlaylistAdapter.getLocations(groupPosition);
@@ -491,6 +500,9 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
                 default:
                     return true;
             }
+            if (groupPosition >= adapter.getCount())
+                return false;
+            medias = adapter.getLocations(groupPosition);
         }
 
         if (append)
