@@ -3,6 +3,7 @@
  * TimePickerDialogFragment.java
  * ****************************************************************************
  * Copyright © 2015 VLC authors and VideoLAN
+ * Author: Geoffrey Métais
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,8 +31,8 @@ import android.widget.TimePicker;
 
 import org.videolan.libvlc.LibVLC;
 import org.videolan.libvlc.LibVlcUtil;
+import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
-import org.videolan.vlc.gui.video.AdvOptionsDialog;
 import org.videolan.vlc.util.VLCInstance;
 
 import java.util.Calendar;
@@ -48,6 +49,7 @@ public class TimePickerDialogFragment extends DialogFragment implements TimePick
 
     @Override
     public Dialog onCreateDialog(Bundle savedInstanceState) {
+        setStyle(STYLE_NO_FRAME, R.attr.advanced_options_style);
         action = getArguments().getInt("action");
         boolean is24 = true;
         int hour = 0;
