@@ -22,7 +22,6 @@ package org.videolan.vlc.gui.video;
 
 import android.annotation.TargetApi;
 import android.app.Activity;
-import android.app.AlertDialog;
 import android.content.BroadcastReceiver;
 import android.content.Context;
 import android.content.Intent;
@@ -35,6 +34,7 @@ import android.os.Environment;
 import android.os.Handler;
 import android.preference.PreferenceManager;
 import android.support.v4.app.FragmentActivity;
+import android.support.v7.app.AlertDialog;
 import android.util.DisplayMetrics;
 import android.util.Log;
 import android.view.ContextMenu;
@@ -54,8 +54,6 @@ import android.widget.PopupMenu;
 import android.widget.PopupMenu.OnMenuItemClickListener;
 import android.widget.TextView;
 
-import org.videolan.libvlc.LibVLC;
-import org.videolan.libvlc.LibVlcException;
 import org.videolan.libvlc.LibVlcUtil;
 import org.videolan.libvlc.Media;
 import org.videolan.vlc.MediaDatabase;
@@ -65,7 +63,7 @@ import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.Thumbnailer;
 import org.videolan.vlc.audio.AudioServiceController;
-import org.videolan.vlc.gui.BrowserFragment;
+import org.videolan.vlc.gui.browser.MediaBrowserFragment;
 import org.videolan.vlc.gui.CommonDialogs;
 import org.videolan.vlc.gui.MainActivity;
 import org.videolan.vlc.gui.SecondaryActivity;
@@ -81,10 +79,12 @@ import java.util.List;
 import java.util.concurrent.BrokenBarrierException;
 import java.util.concurrent.CyclicBarrier;
 
-public class VideoGridFragment extends BrowserFragment implements ISortable, IVideoBrowser, SwipeRefreshLayout.OnRefreshListener, AdapterView.OnItemClickListener {
+public class VideoGridFragment extends MediaBrowserFragment implements ISortable, IVideoBrowser, SwipeRefreshLayout.OnRefreshListener, AdapterView.OnItemClickListener {
 
     public final static String TAG = "VLC/VideoListFragment";
 
+    public final static String KEY_GROUP = "key_group";
+
     protected static final String ACTION_SCAN_START = "org.videolan.vlc.gui.ScanStart";
     protected static final String ACTION_SCAN_STOP = "org.videolan.vlc.gui.ScanStop";
     protected static final int UPDATE_ITEM = 0;
@@ -109,7 +109,6 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
 
     private MainActivity mMainActivity;
     private AudioServiceController mAudioController;
-    private boolean mReady = true;
 
     // Gridview position saved in onPause()
     private int mGVFirstVisiblePos;
@@ -126,6 +125,8 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
         mVideoAdapter = new VideoListAdapter(getActivity(), this);
         mMediaLibrary = MediaLibrary.getInstance();
 
+        if (savedInstanceState != null)
+            setGroup(savedInstanceState.getString(KEY_GROUP));
         /* Load the thumbnailer */
         FragmentActivity activity = getActivity();
         if (activity != null)
@@ -220,6 +221,12 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
             mThumbnailer.start(this);
     }
 
+    @Override
+    public void onSaveInstanceState(Bundle outState) {
+        super.onSaveInstanceState(outState);
+        outState.putString(KEY_GROUP, mGroup);
+    }
+
     @Override
     public void onDestroyView() {
         getActivity().unregisterReceiver(messageReceiverVideoListFragment);
@@ -284,7 +291,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
             return;
         if (media instanceof MediaGroup) {
             MainActivity activity = (MainActivity)getActivity();
-            activity.showSecondaryFragment("videoGroupList", media.getTitle());
+            activity.showSecondaryFragment(SecondaryActivity.VIDEO_GROUP_LIST, media.getTitle());
         }
         else
             playVideo(media, false);
@@ -295,48 +302,49 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
     }
 
     protected void playAudio(MediaWrapper media) {
-        mAudioController.load(media.getLocation(), true);
+        mAudioController.load(media.getLocation());
     }
 
     private boolean handleContextItemSelected(MenuItem menu, int position) {
+        if (position >= mVideoAdapter.getCount())
+            return false;
         MediaWrapper media = mVideoAdapter.getItem(position);
         if (media == null)
             return false;
-        switch (menu.getItemId())
-        {
-        case R.id.video_list_play_from_start:
-            playVideo(media, true);
-            return true;
-        case R.id.video_list_play_audio:
-            playAudio(media);
-            return true;
-        case R.id.video_list_info:
-            Activity activity = getActivity();
-            if (activity instanceof MainActivity)
-                ((MainActivity)activity).showSecondaryFragment("mediaInfo", media.getLocation());
-            else {
-                Intent i = new Intent(activity, SecondaryActivity.class);
-                i.putExtra("fragment", "mediaInfo");
-                i.putExtra("param", media.getLocation());
-                startActivity(i);
-            }
-            return true;
-        case R.id.video_list_delete:
-            AlertDialog alertDialog = CommonDialogs.deleteMedia(
-                    getActivity(),
-                    media.getLocation(),
-                    new VLCRunnable(media) {
-                        @Override
-                        public void run(Object o) {
-                            MediaWrapper media = (MediaWrapper) o;
-                            mMediaLibrary.getMediaItems().remove(media);
-                            mVideoAdapter.remove(media);
-                            if (mAudioController.getMediaLocations().contains(media.getLocation()))
-                                mAudioController.removeLocation(media.getLocation());
-                        }
-                    });
-            alertDialog.show();
-            return true;
+        switch (menu.getItemId()){
+            case R.id.video_list_play_from_start:
+                playVideo(media, true);
+                return true;
+            case R.id.video_list_play_audio:
+                playAudio(media);
+                return true;
+            case R.id.video_list_info:
+                Activity activity = getActivity();
+                if (activity instanceof MainActivity)
+                    ((MainActivity)activity).showSecondaryFragment(SecondaryActivity.MEDIA_INFO, media.getLocation());
+                else {
+                    Intent i = new Intent(activity, SecondaryActivity.class);
+                    i.putExtra("fragment", "mediaInfo");
+                    i.putExtra("param", media.getLocation());
+                    startActivity(i);
+                }
+                return true;
+            case R.id.video_list_delete:
+                AlertDialog alertDialog = CommonDialogs.deleteMedia(
+                        getActivity(),
+                        media.getLocation(),
+                        new VLCRunnable(media) {
+                            @Override
+                            public void run(Object o) {
+                                MediaWrapper media = (MediaWrapper) o;
+                                mMediaLibrary.getMediaItems().remove(media);
+                                mVideoAdapter.remove(media);
+                                if (mAudioController.getMediaLocations().contains(media.getLocation()))
+                                    mAudioController.removeLocation(media.getLocation());
+                            }
+                        });
+                alertDialog.show();
+                return true;
         }
         return false;
     }
@@ -366,7 +374,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
             hasInfo = true;
         menu.findItem(R.id.video_list_info).setVisible(hasInfo);
         menu.findItem(R.id.video_list_delete).setVisible(!LibVlcUtil.isLolliPopOrLater() ||
-                mediaWrapper.getLocation().startsWith("file://"+ Environment.getExternalStorageDirectory().getPath()));
+                mediaWrapper.getLocation().startsWith("file://" + Environment.getExternalStorageDirectory().getPath()));
     }
 
     @Override
@@ -459,7 +467,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
                                 mThumbnailer.addJob(item);
                         }
                     }
-                    if (mReady)
+                    if (mReadyToDisplay)
                         display();
                 }
             }).start();
@@ -544,14 +552,6 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
             MediaLibrary.getInstance().loadMediaItems(getActivity(), true);
     }
 
-    @Override
-    public void setReadyToDisplay(boolean ready) {
-        if (ready && !mReady)
-            display();
-        else
-            mReady = ready;
-    }
-
     @Override
     public void display() {
         if (getActivity() != null)
@@ -559,7 +559,7 @@ public class VideoGridFragment extends BrowserFragment implements ISortable, IVi
                 @Override
                 public void run() {
                     mViewNomedia.setVisibility(mVideoAdapter.getCount()>0 ? View.GONE : View.VISIBLE);
-                    mReady = true;
+                    mReadyToDisplay = true;
                     mVideoAdapter.setNotifyOnChange(true);
                     mVideoAdapter.sort();
                     mGVFirstVisiblePos = mGridView.getFirstVisiblePosition();
