@@ -36,6 +36,8 @@ import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
+import org.videolan.vlc.VLCCallbackTask;
+import org.videolan.vlc.audio.AudioServiceController;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
 
 import android.annotation.TargetApi;
@@ -202,15 +204,47 @@ public class Util {
     public static void openMedia(Context context, final MediaWrapper media){
         if (media == null)
             return;
-        String mrl = Uri.decode(media.getLocation());
+        String mrl = media.getLocation();
         if (media.getType() == MediaWrapper.TYPE_VIDEO)
             VideoPlayerActivity.start(context, mrl, media.getTitle());
         else if (media.getType() == MediaWrapper.TYPE_AUDIO)
             openStream(context, mrl);
     }
 
+    public static  void openList(Context context, final List<String> list, final int position){
+        VLCCallbackTask task = new VLCCallbackTask(context){
+            @Override
+            public void run() {
+                AudioServiceController c = AudioServiceController.getInstance();
+
+                      /* Use the audio player by default. If a video track is
+                       * detected, then it will automatically switch to the video
+                       * player. This allows us to support more types of streams
+                       * (for example, RTSP and TS streaming) where ES can be
+                       * dynamically adapted rather than a simple scan.
+                       */
+                c.load(list, position);
+            }
+        };
+        task.execute();
+    }
+
     public static void openStream(Context context, final String uri){
-        VideoPlayerActivity.start(context, uri);
+        VLCCallbackTask task = new VLCCallbackTask(context){
+            @Override
+            public void run() {
+                AudioServiceController c = AudioServiceController.getInstance();
+
+                      /* Use the audio player by default. If a video track is
+                       * detected, then it will automatically switch to the video
+                       * player. This allows us to support more types of streams
+                       * (for example, RTSP and TS streaming) where ES can be
+                       * dynamically adapted rather than a simple scan.
+                       */
+                c.load(uri);
+            }
+        };
+        task.execute();
     }
 
     private static String getMediaString(Context ctx, int id) {
@@ -310,6 +344,10 @@ public class Util {
     public static boolean canWrite(String path){
         if (path == null)
             return false;
+        if (path.startsWith("file://"))
+            path = path.substring(7);
+        if (!path.startsWith("/"))
+            return false;
         if (path.startsWith(Environment.getExternalStorageDirectory().getPath()))
             return true;
         if (LibVlcUtil.isLolliPopOrLater())
