@@ -2,6 +2,7 @@
  * MediaItemDetailsFragment.java
  *****************************************************************************
  * Copyright © 2014-2015 VLC authors, VideoLAN and VideoLabs
+ * Author: Geoffrey Métais
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -162,7 +163,7 @@ public class MediaItemDetailsFragment extends DetailsFragment implements AudioSe
 
     @Override
     public void onConnectionSuccess() {
-        mAudioController.load(mMedia.getLocation(), true);
+        mAudioController.load(mMedia.getLocation());
     }
 
     @Override
