@@ -2,6 +2,7 @@
  * RecommendationsService.java
  *****************************************************************************
  * Copyright © 2014-2015 VLC authors, VideoLAN and VideoLabs
+ * Author: Geoffrey Métais
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +39,7 @@ import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.gui.PreferencesActivity;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
+import org.videolan.vlc.util.BitmapUtil;
 import org.videolan.vlc.util.WeakHandler;
 
 import java.util.ArrayList;
@@ -60,6 +62,10 @@ public class RecommendationsService extends IntentService {
     public void onCreate() {
         super.onCreate();
         mContext = this;
+        if (mNotificationManager == null) {
+            mNotificationManager = (NotificationManager)
+                    mContext.getSystemService(Context.NOTIFICATION_SERVICE);
+        }
     }
 
     @Override
@@ -73,11 +79,6 @@ public class RecommendationsService extends IntentService {
         if (movie == null)
             return;
 
-        if (mNotificationManager == null) {
-            mNotificationManager = (NotificationManager)
-                    mContext.getSystemService(Context.NOTIFICATION_SERVICE);
-        }
-
         //TODO
 //        if (mBackgroundUri != movie.getBackgroundUri()) {
 //            extras.putString(EXTRA_BACKGROUND_IMAGE_URL, movie.getBackgroundUri());
@@ -92,16 +93,15 @@ public class RecommendationsService extends IntentService {
                         .setPriority(priority)
                         .setLocalOnly(true)
                         .setOngoing(true)
-                        .setColor(mContext.getResources().getColor(R.color.orange500))
+                        .setColor(mContext.getResources().getColor(R.color.orange800))
                         .setCategory("recommendation")
-                        .setLargeIcon(mMediaDatabase.getPicture(mContext, movie.getLocation()))
+                        .setLargeIcon(BitmapUtil.getPictureFromCache(movie))
                         .setSmallIcon(R.drawable.icon)
                         .setContentIntent(buildPendingIntent(movie, id))
         ).build();
 
         // post the recommendation to the NotificationManager
         mNotificationManager.notify(id, notification);
-        mNotificationManager = null;
     }
 
     private PendingIntent buildPendingIntent(MediaWrapper mediaWrapper, int id) {
@@ -129,6 +129,7 @@ public class RecommendationsService extends IntentService {
     }
 
     private boolean doRecommendations() {
+        mNotificationManager.cancelAll();
         String last = Uri.decode(PreferenceManager.getDefaultSharedPreferences(mContext).getString(PreferencesActivity.VIDEO_LAST, null));
         int id = 0;
         if (last != null) {
@@ -147,8 +148,8 @@ public class RecommendationsService extends IntentService {
                 buildRecommendation(mediaWrapper, ++id, Notification.PRIORITY_DEFAULT);
             }
             if (id == NUM_RECOMMANDATIONS)
-                return true;
+                break;
         }
-        return false;
+        return true;
     }
 }
